==> green-core-1.70.1.tgz: package/components/theme/theme.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { css, unsafeCSS } from "lit";
import { property } from "lit/decorators.js";
import { GdsElement } from "../../gds-element";
import { gdsCustomElement, html } from "../../scoping";
import { colorsDark, colorsLight, tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles";
import { watch } from "../../utils/decorators";
let GdsTheme = class extends GdsElement {
  constructor() {
    super(...arguments);
    this.colorScheme = "light";
    this.designVersion = "2016";
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-theme");
    this._dynamicStylesController.inject(
      "dark",
      unsafeCSS(`:host {${colorsDark}}`)
    );
  }
  render() {
    return html`<slot></slot>`;
  }
  _onColorSchemeChange() {
    if (this.colorScheme === "dark") {
      this._dynamicStylesController.inject(
        "color-scheme",
        unsafeCSS(`:host { ${colorsDark}}`)
      );
    } else {
      this._dynamicStylesController.inject(
        "color-scheme",
        unsafeCSS(`:host { ${colorsLight}}`)
      );
    }
    this.dispatchEvent(
      new CustomEvent("gds-color-scheme-changed", {
        detail: { colorScheme: this.colorScheme }
      })
    );
  }
  _onDesignVersionChange() {
    this.dispatchEvent(
      new CustomEvent("gds-design-version-changed", {
        detail: { designVersion: this.designVersion }
      })
    );
  }
};
GdsTheme.styles = [
  tokens,
  css`
      :host {
        display: contents;
      }
    `
];
__decorateClass([
  property({ reflect: true, attribute: "color-scheme" })
], GdsTheme.prototype, "colorScheme", 2);
__decorateClass([
  property({ reflect: true, attribute: "design-version" })
], GdsTheme.prototype, "designVersion", 2);
__decorateClass([
  watch("colorScheme")
], GdsTheme.prototype, "_onColorSchemeChange", 1);
__decorateClass([
  watch("designVersion")
], GdsTheme.prototype, "_onDesignVersionChange", 1);
GdsTheme = __decorateClass([
  gdsCustomElement("gds-theme")
], GdsTheme);
export {
  GdsTheme
};

==> green-core-1.71.0.tgz: package/components/theme/theme.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { css, unsafeCSS } from "lit";
import { property } from "lit/decorators.js";
import { GdsElement } from "../../gds-element.js";
import { gdsCustomElement, html } from "../../scoping.js";
import { colorsDark, colorsLight, tokens } from "../../tokens.style";
import { TransitionalStyles } from "../../transitional-styles.js";
import { watch } from "../../utils/decorators/index.js";
let GdsTheme = class extends GdsElement {
  constructor() {
    super(...arguments);
    this.colorScheme = "light";
    this.designVersion = "2016";
  }
  connectedCallback() {
    super.connectedCallback();
    TransitionalStyles.instance.apply(this, "gds-theme");
    this._dynamicStylesController.inject(
      "dark",
      unsafeCSS(`:host {${colorsDark}}`)
    );
  }
  render() {
    return html`<slot></slot>`;
  }
  _onColorSchemeChange() {
    if (this.colorScheme === "dark") {
      this._dynamicStylesController.inject(
        "color-scheme",
        unsafeCSS(`:host { ${colorsDark}}`)
      );
    } else {
      this._dynamicStylesController.inject(
        "color-scheme",
        unsafeCSS(`:host { ${colorsLight}}`)
      );
    }
    this.dispatchEvent(
      new CustomEvent("gds-color-scheme-changed", {
        detail: { colorScheme: this.colorScheme }
      })
    );
  }
  _onDesignVersionChange() {
    this.dispatchEvent(
      new CustomEvent("gds-design-version-changed", {
        detail: { designVersion: this.designVersion }
      })
    );
  }
};
GdsTheme.styles = [
  tokens,
  css`
      :host {
        display: contents;
      }
    `
];
__decorateClass([
  property({ reflect: true, attribute: "color-scheme" })
], GdsTheme.prototype, "colorScheme", 2);
__decorateClass([
  property({ reflect: true, attribute: "design-version" })
], GdsTheme.prototype, "designVersion", 2);
__decorateClass([
  watch("colorScheme")
], GdsTheme.prototype, "_onColorSchemeChange", 1);
__decorateClass([
  watch("designVersion")
], GdsTheme.prototype, "_onDesignVersionChange", 1);
GdsTheme = __decorateClass([
  gdsCustomElement("gds-theme")
], GdsTheme);
export {
  GdsTheme
};
